# Change log

## [Unreleased]

## [1.0.0] - 2026-03-11

Initial release 🎉

## [0.0.1] - 2026-03-11

Initial beta release 🎉

[0.0.1]: https://github.com/taminomara/cl-keeper/releases/tag/v0.0.1
[1.0.0]: https://github.com/taminomara/cl-keeper/compare/v0.0.1...v1.0.0
[unreleased]: https://github.com/taminomara/cl-keeper/compare/v1.0.0...HEAD
